# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fintekkers/requests/position/query_position_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fintekkers.models.position import position_pb2 as fintekkers_dot_models_dot_position_dot_position__pb2
from fintekkers.requests.position import query_position_request_pb2 as fintekkers_dot_requests_dot_position_dot_query__position__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:fintekkers/requests/position/query_position_response.proto\x12\x1c\x66intekkers.requests.position\x1a)fintekkers/models/position/position.proto\x1a\x39\x66intekkers/requests/position/query_position_request.proto\"\xf0\x01\n\x1aQueryPositionResponseProto\x12\x14\n\x0cobject_class\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12Q\n\x10position_request\x18\x0b \x01(\x0b\x32\x37.fintekkers.requests.position.QueryPositionRequestProto\x12\x1a\n\x12reporting_currency\x18\x0c \x01(\t\x12<\n\tpositions\x18\x1e \x03(\x0b\x32).fintekkers.models.position.PositionProtoB\x1f\x42\x1bQueryPositionResponseProtosP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fintekkers.requests.position.query_position_response_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\033QueryPositionResponseProtosP\001'
  _QUERYPOSITIONRESPONSEPROTO._serialized_start=195
  _QUERYPOSITIONRESPONSEPROTO._serialized_end=435
# @@protoc_insertion_point(module_scope)
